@@ -19,6 +19,7 @@
 
 
 #include <ortp/payloadtype.h>
+#include <ortp/rtpprofile.h>
 
 char offset127=127; 
 char offset0xD5=(char)0xD5; 
@@ -235,6 +236,50 @@ PayloadType payload_type_g726_16={
 	CHANNELS(1)
 };
 
+PayloadType payload_type_aal2_g726_40={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("AAL2-G726-40"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_aal2_g726_32={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("AAL2-G726-32"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_aal2_g726_24={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("AAL2-G726-24"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_aal2_g726_16={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("AAL2-G726-16"),
+	CHANNELS(1)
+};
+
 PayloadType payload_type_mpv=
 {
 	TYPE( PAYLOAD_VIDEO),
@@ -385,7 +430,7 @@ PayloadType payload_type_amrwb={
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
-	NORMAL_BITRATE(0),
+	NORMAL_BITRATE(23850),
 	MIME_TYPE ("AMR-WB"),
 	CHANNELS(1)
 };
@@ -490,17 +535,37 @@ PayloadType payload_type_jpeg={
 	CHANNELS(0)
 };
 
+PayloadType payload_type_vp8={
+	TYPE( PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE ("VP8"),
+	CHANNELS(0)
+};
 
 PayloadType	payload_type_t140={
-	PAYLOAD_AUDIO_PACKETIZED, /*type */
-	1000,
-	0,
-	NULL,
-	0,
-	0,
-	"t140",
-	0,
-	0
+	TYPE( PAYLOAD_TEXT),
+	CLOCK_RATE(1000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(0),
+	MIME_TYPE ("t140"),
+	CHANNELS(0)
+};
+
+PayloadType payload_type_t140_red={
+	TYPE(PAYLOAD_TEXT),
+	CLOCK_RATE(1000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(0),
+	MIME_TYPE("red"),
+	CHANNELS(0)
 };
 
 PayloadType	payload_type_x_udpftp={
@@ -526,4 +591,79 @@ PayloadType payload_type_g722={
        CHANNELS(1)
 };
 
+PayloadType payload_type_silk_nb={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE(10000),
+	MIME_TYPE ("SILK"),
+	CHANNELS(1)
+};
 
+PayloadType payload_type_silk_mb={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(12000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE(15000),
+	MIME_TYPE ("SILK"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_silk_wb={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(16000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE(20000),
+	MIME_TYPE ("SILK"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_silk_swb={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(24000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE(30000),
+	MIME_TYPE ("SILK"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_aaceld_22k={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(22050),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE(32000),
+	MIME_TYPE ("mpeg4-generic"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_aaceld_44k={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(44100),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE(64000),
+	MIME_TYPE ("mpeg4-generic"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_opus = {
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(48000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(20000),
+	MIME_TYPE("opus"),
+	CHANNELS(1)
+};
